function GenRectMesh(filename,elwide,eltall,xleft,xright,ybottom,ytop)
%GenRectMesh generates a uniform rectangular mesh that is elwide elements wide,
% eltall elements tall, from xleft to xright on the x-axis, and from ybottom
% to ytop on the y-axis. A file of name "filename" is produced with the X
% nodal coordinates, labelled X1, the Y nodal coordinates, labeled X1, the
% element connectivity, labeled elcon. 
% Syntax: GenRectMesh('filename',elwide,eltall,xleft,xright,ybottom,ytop)

X1_seed = linspace(xleft,xright,elwide+1);
X2_seed = linspace(ytop, ybottom, eltall+1);

[X Y] = meshgrid(X1_seed, X2_seed);

%output X1 X2 data in a 2 column format as opposed to 2 block formats
nnodes_tall = size(X,1); %number of rows
nnodes_wide = size(Y,2); % number of columns

%initialize the X1 vector
X1 = X(:,1);
X2 = Y(:,1);
for ii =2:1:nnodes_wide
  X1 = cat(1,X1,X(:,ii));
  X2 = cat(1,X2,Y(:,ii));
end 
%******** from fempse function quadcon.m ********************
% check input
if elwide >= 1 & eltall >= 1
  % accept the input data (elwide and eltall)
else
  error('inputs must be >= 1')
  return;
end

% setup
nelements = elwide * eltall;
first_el = zeros(1,4);
first_row = zeros(elwide,4);
elcon = zeros(nelements,4);

first_el = [2 eltall+3 eltall+2 1];     % con table for first element

% constuct connection table for first column of elements
for i=1:eltall,
  first_col(i,:) = first_el + (i-1);
end

% construct element connectivity table a column of elements at a time
for j=1:elwide,
  elcon(1+(j-1)*eltall:j*eltall,:)=first_col + ((j-1)*(eltall+1));
end

size_elcon = size(elcon);

%list the boundary condition nodes
nodes = zeros(nnodes_tall, nnodes_wide);
count = 1;
for ii=1:1:nnodes_wide
	for jj=1:1:nnodes_tall
	nodes(jj,ii) = count;
	count = count + 1;
	end
end

%fprintf(filename);
fid = fopen(filename,'w');
fprintf(fid,['X1 X2  ' num2str(nnodes_wide*nnodes_tall) '  '  num2str(2) '\n']);
for ii=1:1:nnodes_tall*nnodes_wide
	fprintf(fid,'%f %f\n',X1(ii),X2(ii));
end
fprintf(fid,['elcon  ' num2str(size_elcon(1)) '  ' num2str(size_elcon(2)) '\n']);
for ii=1:1:size_elcon(1)
	for jj=1:1:size_elcon(2)
	fprintf(fid,'%i',elcon(ii,jj));
	fprintf(fid,' ');
	end
	fprintf(fid,'\n');
end

for kk=1:1:4 %4 walls

if kk==1 
bc = 'XL';
list = (nodes(:,1))';
elseif kk==2 
bc = 'XR';
list = (nodes(:,nnodes_wide))';
elseif kk==3 
bc = 'YT';
list = nodes(1,:);
elseif kk==4 
bc = 'YB';
list = nodes(nnodes_tall,:);
end

fprintf(fid,[ bc ' ' num2str(length(list)) '\n']);
for ii=1:1:length(list)
fprintf(fid,'%i', list(ii));
fprintf(fid,' ');
end
fprintf(fid,'\n');
end

node_size = size(nodes);
row_blank = floor(node_size(1)/2);
col_blank = floor(node_size(2)/2);
fprintf(fid,['BLANK ' num2str(row_blank.*col_blank) '\n']);
for ii=2:1:col_blank+1
  for jj=2:1:row_blank+1
	fprintf(fid, '%i ',nodes(jj,ii) ); 
  end
end
fclose(fid);
disp(' ');
disp(['Mesh generation complete. Data stored in file: ',filename]);
