function gmat=ass1dH(gscalar,escalar,hyp,mexp,lmat_name,nvar);
%  usage:  ass1dH(gscalar,escalar,hyp,mexp,lmat,mesh)
%
%  Assembles 1d finite element matrices.  Uses square Hermite basis
%  element library matrices.   Returns the  assembled  global matirx. 
%
%  gscalar - global scalar data (default unity)
%  escalar - element data (row matrix, default unity)
%  hyp     - ignored  
%  mexp    - mesh measure exponent
%  lmat    - element library matrix
%  nvar    - nodal variable (default unity) diag(nvar)
%
%  Any of the first two arguments may be omitted by supplying an 
%  empty matrix ([]) in their place.    Ones will be inserted for any
%  legally omitted arguments.  The third argument is present for format
%  compatablity with ass1d.m.  Its value is ignored.

global X1               % a row matrix, nodal coordinate  data
global SPARSTORE	% a flag to indicate if sparse storage is desired
load femlib;

% the eval functionality does not HAVE to be used this way, but it is
%necessary for multi-dimensional problems. Thus, it is applied here to maintain
%consistency in the user generated script.
lmat = eval(lmat_name);

nnodes = size(X1,2);   %  number of nodes in the mesh
enodes = 2;  %  number of nodes per element
emat = zeros(4,4);   % allocate space for element matrix
nelements = (nnodes-1)/(enodes-1); % number of elements

%  check to see that X1 is strictly increasing.
for i=1:nnodes-1
  if X1(i+1)-X1(i) <= 0,
    % X1 is not increasing, generate error
    error('nodal coordinates must increase from left to right')
  end
end

% Allocate memory for global matrix (full matirx is stored)
gmat = zeros(2*nnodes,2*nnodes); % creates 2*nnodes by 2*nnodes matirx of zeros

%  provide for empty arguments
if length(gscalar)==0;
  gscalar = 1;
end;
if length(escalar)==0;
  escalar = ones(1,nelements); % row of ones
end;

%  initialize left and right dof addresses for current element
mleft = 1;
mright = 4;

% Main loop
for jj=1:nelements;
  %  form mesh measure matrix 
  le = X1(jj+1) - X1(jj); % mesh measure for the current element
  mmv = [1 le 1 le];  % mesh measure vector.  used to form mesh measure matrix
  mmm = mmv' * mmv;  % basic mesh measure matrix
  mmm = mmm * (le^mexp); 
 
  % form element matrix from element library matrix
  emat =  (lmat .* mmm) * escalar(jj) * gscalar;

% assemble element matrix into global matrix
  gmat(mleft:mright,mleft:mright) = gmat(mleft:mright,mleft:mright) + emat;

% update left and right node addresses for the next element
  mleft = mleft + 2;
  mright = mright + 2;
end;

% apply the nvar data if present
if isempty(nvar)
  % do nothing
else
  gmat = gmat * diag(nvar(:));
end
