function gmat=ass1dH(gscalar,escalar,hyp,mexp,lmat,mesh);
%  usage:  ass1dH(gscalar,escalar,hyp,mexp,lmat,mesh)
%
%  Assembles 1d finite element matrices.  Uses square Hermite basis
%  element library matrices.   Returns the  assembled  global matirx. 
%
%  gscalar - global scalar data (default unity)
%  escalar - element data (row matrix, default unity)
%  hyp     - ignored  
%  mexp    - mesh measure exponent
%  lmat    - element library matrix
%  mesh    - nodal values of the mesh  (row matrix)
%
%  Any of the first two arguments may be omitted by supplying an 
%  empty matrix ([]) in their place.    Ones will be inserted for any
%  legally omitted arguments.  The third argument is present for format
%  compatablity with ass1d.m.  Its value is ignored.

nnodes = size(mesh,2);   %  number of nodes in the mesh
enodes = 2;  %  number of nodes per element
emat = zeros(4,4);   % allocate space for element matrix
nelements = (nnodes-1)/(enodes-1); % number of elements

% Allocate memory for global matrix (full matirx is stored)
gmat = zeros(2*nnodes,2*nnodes); % creates 2*nnodes by 2*nnodes matirx of zeros

%  provide for empty arguments
if length(gscalar)==0;
  gscalar = 1;
end;
if length(escalar)==0;
  escalar = ones(1,nelements); % row of ones
end;

%  initialize left and right dof addresses for current element
mleft = 1;
mright = 4;

% Main loop
for jj=1:nelements;
  %  form mesh measure matrix 
  le = mesh(jj+1) - mesh(jj); % mesh measure for the current element
  mmv = [1 le 1 le];  % mesh measure vector.  used to form mesh measure matrix
  mmm = mmv' * mmv;  % basic mesh measure matrix
  mmm = mmm * (le^mexp); 
 
  % form element matrix from element library matrix
  emat =  (lmat .* mmm) * escalar(jj) * gscalar;

% assemble element matrix into global matrix
  gmat(mleft:mright,mleft:mright) = gmat(mleft:mright,mleft:mright) + emat;

% update left and right node addresses for the next element
  mleft = mleft + 2;
  mright = mright + 2;
end;
