function DIFFe = do_DIFFe_q0(ETAe)
% usage:  DIFFe = do_DIFFe_q0(ETAe)
% Calculates element diffusion matrices for linear quad elements, no
% quadrature, modulo determinant and ke.  Ref: FE123, eq 6.47.

% library matrices from FE123, eq 6.48:
B211B = 1/6 * [2 -2 -1 1;-2 2 1 -1;-1 1 2 -2;1 -1 -2 2];
B222B = 1/6 * [2 1 -1 -2;1 2 -2 -1;-1 -2 2 1;-2 -1 1 2];
B212B = 1/4 * [1 0 -1 0;0 -1 0 1;-1 0 1 0;0 1 0 -1];
B221B = B212B;

% B2IKB will be a cell array.  Each cell of B2IKB will be a matrix, so
% B2IKB is a matrix of matrices.  Matlab uses braces {} to specify
% entries in cell arrays.
B2IKB=cell(2,2);			% create a 2 by 2 cell array
B2IKB{1,1} = B211B;
B2IKB{2,2} = B222B;
B2IKB{1,2} = B212B;
B2IKB{2,1} = B221B;

nelements = size(ETAe,3);
DIFFe = zeros(4,4,nelements);   	% reserve memory for DIFFe

for el=1:nelements			% loop over the elements
  for i=1:2
    for j=1:2
      for k=1:2
	DIFFe(:,:,el) = DIFFe(:,:,el) + ...
	  ETAe(i,j,el) * ETAe(k,j,el) * B2IKB{i,k};
      end
    end
  end
end

