function [DETe,DETeI,ETAe]=do_ETAe_q0(X1,X2,ELCON)
% usage:  [DETe,DETeI,ETAe]=do_ETAe_q0(X1,X2,ELCON)
% calculates det and dETAi/dXj for linear quad elements, no quadrature.
% ref:  Finite Elements 1-2-3
%
%  DETe -  column array of element determinants
%  DETeI - 1/DETe
%  ETAe -  dETAi/dXj, calculated by eq 6.44.  One 2x2 matrix per element.
%  X1, X2  -  arrays of nodal coordinates
%  ELCON - Node connectivity table.  The ith row of ELCON is an ordered list
%            of node numbers.  The corresponding nodes are the veritces of
%            the ith element.
%

% number of elements is equal to the number of rows of ELCON
nelements = size(ELCON,1);

% reserve memory for output variables
DETe = zeros(nelements,1);
DETeI = zeros(nelements,1);
ETAe = zeros(2,2,nelements);

% make sure X1e and X2e (which hold the nodal coordinates for the current 
% element) are column arrays
X1e = zeros(4,1);
X2e = zeros(4,1);

% loop over all the elements
for i=1:nelements,
  % find the nodal coordinates for the element
  X1e(:) = X1(ELCON(i,:));
  X2e(:) = X2(ELCON(i,:));
  
  % calculate ETAe via eq 6.44
  ETAe(1,1,i) = (X2e(4)-X2e(1)+X2e(3)-X2e(2))/4;
  ETAe(1,2,i) = (X1e(4)-X1e(1)+X1e(3)-X1e(2))/4;
  ETAe(2,1,i) = (X2e(2)-X2e(1)+X2e(3)-X2e(4))/4;
  ETAe(2,2,i) = (X1e(2)-X1e(1)+X1e(3)-X1e(4))/4;
   
  % calculate DETe
  DETe(i) = det(ETAe(:,:,i));
  if DETe(i) <= 0,
    error(['determinant of element ' num2str(i) ' is negative or zero'])
  end
  DETeI(i) = 1/DETe(i);	  
end