function KUVe = do_KUVe_2Dt(k_nu,ZETAe)
% usage:  KUVe = do_KUVe_2dt(k_nu,ZETAe)
% Calculates element stiffness matrices for plane stress/plane strain
% problems using 2D linear triangles.  These matrices include k_nu, but
% are modulo DETe.  Ref: FE123, eq 5.163a


% B2IKL will be a cell array.  Each cell of B2IKL will be a matrix, so
% B2IKL is a array of matrices.  Matlab uses braces {} to specify
% entries in cell arrays.
B2IKL = cell(3,3);			% create a 3 by 3 cell array
% create the entries in B2IKL per eq 5.32
for i=1:3
  for k=1:3
    B2IKL{i,k} = zeros(3,3);
    % set the i,k entry of the i,k matrix to 1
    B2IKL{i,k}(i,k) = 1;
  end
end

nelements = size(ZETAe,3);
KUVe = zeros(3,3,nelements);    	% reserve memory for DIFFe

for el=1:nelements			% loop over the elements
  for i=1:3
    for k=1:3
      KUVe(:,:,el) = KUVe(:,:,el) + ...
	 1/2 *  B2IKL{i,k} * (k_nu * ZETAe(i,1,el)*ZETAe(k,2,el) ...
	                           - ZETAe(i,2,el)*ZETAe(k,1,el));
    end
  end
end

