function [ZETAe,DETe]=do_ZETAe_2Dt(X,Y,TRI)
% calculates det and dZETAi/dXj for linear triangle elements.
% ref:  Finite Elements 1-2-3
%
%  DETe -  element determinants (2*Ae) calculated by eq 5.11. 
%  ZETAe - dZETAi/dXj, arranged in matrix form, per eq 5.29, without the
%           1/(2*Ae).  ZETA is a three index array.  Each plane of 
%           ZETA, ZETA(:,:,i) , is a 2D array with the value of the
%           index i corresponding to a particular element.
%  X,Y  -  arrays of nodal coordinates
%  TRI  -  Node connectivity table, produced from X and Y by the 
%           delaunay function.
%

% find the number of elements from the dimensions of TRI
nelements = size(TRI,1);

% reserve memory for output variables
DETe = zeros(nelements,1);
rDETe = zeros(nelements,1);
ZETAe = zeros(3,2,nelements);

% make sure Xe and Ye (which hold the nodal coordinates for the current 
% element) are column arrays
Xe = zeros(3,1);
Ye = zeros(3,1);

% loop over all the elements
for i=1:nelements,
  % find the nodal coordinates for the element
  Xe(:) = X(TRI(i,:));
  Ye(:) = Y(TRI(i,:));
  
  % calculate DETe
  DETe(i) = abs(det([ones(3,1), Xe, Ye]));
  if DETe(i) <= 0,
    error('negative det, try doing fliplr(TRI) before calling do_ZETA')
  end
  
  % calculate ZETA
  ZETAe(1,1,i) = Ye(2)-Ye(3);
  ZETAe(1,2,i) = Xe(3)-Xe(2);
  ZETAe(2,1,i) = Ye(3)-Ye(1);
  ZETAe(2,2,i) = Xe(1)-Xe(3);
  ZETAe(3,1,i) = Ye(1)-Ye(2);
  ZETAe(3,2,i) = Xe(2)-Xe(1);
end