function [X_new, Y_new, Q_new]=process2D_data(X,Y,Q,elwide,eltall)
% process2D_data takes the X & Y coordinate data along with a solution
% vector on those coordinates and transforms them to
% the rectangular representation of the domain it spans (the domain
% must be rectangular).
% syntax: [X_new Y_new, Q_new]=process2D_data(X,Y,Q,elwide,eltall)
%	X: column vector of X coordinates in global nodal order
%	Y: column vector of Y coordinates in global nodal order
%	Q: column vector of a solution in global nodal order
%	elwide: number of elements spanning the width of the domain
%	eltall: number of elements spanning the height of the domain
%
% Note that the number of nodes(elements+1) must coincide with the 
% with the size of the column vectors, i.e. the length of the column
% vector must be a multiple of the number of nodes in width AND height.


%ensure that X and Y are column vectors
if(size(X,2) ~= 1 || size(Y,2) ~= 1 || size(Q,2) ~= 1)
	error('X,Y, and Q  must be column vectors');
	return;
end

%check that X and Y are the same size
if(size(X,1) ~= size(Y,1) || size(X,1) ~= size(Q,1))
	error('The X,Y, and Q column vectors are not the same size');
	return;
end

%check that X,Y, and Q are multiples of elwide and eltall. (if X, Y, and Q 
% are same size only need to check X)
if(mod(length(X),elwide+1) ~= 0)
	error('The length of the X and Y coordinate vector must be a multiple of the number of nodes in the width of the domain.');
	return;
end
if(mod(length(X),eltall+1) ~= 0)
	error('The length of the X coordinate vector must be a multiple of the number of nodes in the height of the domain.');
	return;
end

X_new = zeros(eltall+1,elwide+1);
Y_new = zeros(eltall+1,elwide+1);
Q_new = zeros(eltall+1,elwide+1);

counter=0;
for ii=1:1:elwide+1
  for jj=1:1:eltall+1
   	counter=counter+1;
  	X_new(jj,ii) = X(counter);
  	Y_new(jj,ii) = Y(counter);
	Q_new(jj,ii) = Q(counter);
  end
end

disp('end process2D_data');

return;



