function [jac_t, b_t] = threadit(jac,b,numsv)
% usage:   [jac_t, b_t] = threadit(jac,b,numsv)
% Takes a jacobian and right hand side for multi state variable systems
% that was formed by concatenation and threads them together to reduce
% matrix bandwith.  Returns a sparse jac_t.  numsv is the number of state 
% variables.

ndof = size(jac,2);			% total number of deg of freedom
nnodes = ndof/numsv;			% total number of nodes

% calculate permutation vector.
pvec = zeros(1,ndof);
pvec(1) = 1;
for i=2:ndof
  pvec(i) = 1 + floor((i-1)/numsv) + mod(i-1,numsv)*nnodes;
end

% apply permutation vector to i and j indices of the entries in jac
[Indx,Jndx,vals] = find(jac);
Indx_t = Indx(pvec);
Jndx_t = Jndx(pvec);

% reassemble the jacobian in its reordered form
jac_t = sparse(Indx_t,Jndx_t,vals,ndof,ndof);

% apply permutation vector to b
b_t = b(pvec);