function Q = unthreadit(Q_t,numsv)
% usage:   Q = unthreadit(Q_t,numsv)
% Unthreads a solution calculated from a jacobian and right hand side
% processed with 'threadit'. The returned value Q will have numsv
% columns, where numsv is the number of state 
% variables.  The first column of Q is the solution for the first state
% variable, the second column is the solution for the second state
% variable, ect.

ndof = prod(size(Q);			% total number of deg of freedom
nnodes = ndof/numsv;			% total number of nodes

pvec = zeros(1,ndof);
% calculate permutation vector.
for i=1:nnodes
  pvec(i) = 1 + floor(i/numsv) + mod(i,numsv)*nnodes;
end

% apply permutation vector to Q_t
Q_scratch = Q_t(pvec);

% rearange Q_scratch into columns, one for each state variable
Q = reshape(Q_scratch,nnodes,numsv);